@@ -1,12 +1,9 @@
-use crate::id::Id;
-use crate::util::MapWithMut;
+use crate::{id::Id, util::MapWithMut};
 use fxhash::FxHashMap;
 use swc_atoms::js_word;
 use swc_ecma_ast::*;
 use swc_ecma_utils::private_ident;
-use swc_ecma_visit::noop_visit_mut_type;
-use swc_ecma_visit::VisitMut;
-use swc_ecma_visit::VisitMutWith;
+use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith};
 
 #[derive(Default)]
 pub struct KeywordRenamer {
